@@ -172,3 +172,7 @@ class Grocy(object):
 
     def add_generic(self, entity_type, data):
         return self._api_client.add_generic(entity_type, data)
+
+    def delete_entity(self, entity_type, data):
+        return self._api_client.delete_entity(entity_type, data)
+
