@@ -657,7 +657,7 @@ class GrocyApiClient(object):
         return last_change_timestamp
 
     def get_tasks(self) -> List[TaskResponse]:
-        parsed_json = self._do_get_request("objects/tasks", params={'done': '0'})
+        parsed_json = self._do_get_request("objects/tasks", params={'query[]': 'done=0'})
         return [TaskResponse(data) for data in parsed_json]
 
     def get_task(self,  task_id: int) -> TaskResponse:
